<?php
/**
 * Business Lawyer Firm functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Business Lawyer Firm
 */

include get_theme_file_path( 'vendor/wptrt/autoload/src/Business_Lawyer_Firm_Loader.php' );

$Business_Lawyer_Firm_Loader = new \WPTRT\Autoload\Business_Lawyer_Firm_Loader();

$Business_Lawyer_Firm_Loader->business_lawyer_firm_add( 'WPTRT\\Customize\\Section', get_theme_file_path( 'vendor/wptrt/customize-section-button/src' ) );

$Business_Lawyer_Firm_Loader->business_lawyer_firm_register();

if ( ! function_exists( 'business_lawyer_firm_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function business_lawyer_firm_setup() {

		add_theme_support( 'woocommerce' );
		add_theme_support( "responsive-embeds" );
		add_theme_support( "align-wide" );
		add_theme_support( "wp-block-styles" );
		
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

        add_image_size('business-lawyer-firm-featured-header-image', 2000, 660, true);

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus( array(
            'primary' => esc_html__( 'Primary','business-lawyer-firm' ),
	        'footer'=> esc_html__( 'Footer Menu','business-lawyer-firm' ),
        ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'business_lawyer_firm_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 50,
			'flex-width'  => true,
		) );

		add_editor_style( array( '/editor-style.css' ) );
	}
endif;
add_action( 'after_setup_theme', 'business_lawyer_firm_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function business_lawyer_firm_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'business_lawyer_firm_content_width', 1170 );
}
add_action( 'after_setup_theme', 'business_lawyer_firm_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function business_lawyer_firm_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'business-lawyer-firm' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'business-lawyer-firm' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Front Page Sidebar', 'business-lawyer-firm' ),
		'id'            => 'front-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'business-lawyer-firm' ),
        'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h5 class="widget-title">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'business_lawyer_firm_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function business_lawyer_firm_scripts() {

	wp_enqueue_style('business-lawyer-firm-font', business_lawyer_firm_font_url(), array());

	wp_enqueue_style( 'business-lawyer-firm-block-editor-style', get_theme_file_uri('/assets/css/block-editor-style.css') );

	// load bootstrap css
    wp_enqueue_style( 'flatly-css', esc_url(get_template_directory_uri()) . '/assets/css/flatly.css');

    wp_enqueue_style( 'owl.carousel-css', esc_url(get_template_directory_uri()) . '/assets/css/owl.carousel.css');

	wp_enqueue_style( 'business-lawyer-firm-style', get_stylesheet_uri() );

    wp_style_add_data('business-lawyer-firm-style', 'rtl', 'replace');

	// fontawesome
	wp_enqueue_style( 'fontawesome-style', esc_url(get_template_directory_uri()).'/assets/css/fontawesome/css/all.css' );

    wp_enqueue_script('business-lawyer-firm-theme-js', esc_url(get_template_directory_uri()) . '/assets/js/theme-script.js', array('jquery'), '', true );

    wp_enqueue_script('owl.carousel-js', esc_url(get_template_directory_uri()) . '/assets/js/owl.carousel.js', array('jquery'), '', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'business_lawyer_firm_scripts' );

function business_lawyer_firm_font_url(){
	$font_url = '';
	$lato = _x('on','Lato:on or off','business-lawyer-firm');
	$roboto = _x('on','Roboto:on or off','business-lawyer-firm');
	
	if('off' !== $lato ){
		$font_family = array();
		if('off' !== $lato){
			$font_family[] = 'Lato:ital,wght@0,100;0,300;0,400;0,700;0,900;1,100;1,300;1,400;1,700;1,900';
		}
		if('off' !== $roboto){
			$font_family[] = 'Roboto:ital,wght@0,100;0,300;0,400;0,500;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900';
		}
		$query_args = array(
			'family' => urlencode(implode('|',$font_family)),
		);
		$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	}
	return $font_url;
}

/**
 * Enqueue S Header.
 */
function business_lawyer_firm_sticky_header() {

	$business_lawyer_firm_sticky_header = get_theme_mod('business_lawyer_firm_sticky_header');

	$business_lawyer_firm_custom_style= "";

	if($business_lawyer_firm_sticky_header != true){

		$business_lawyer_firm_custom_style .='.stick_header{';

			$business_lawyer_firm_custom_style .='position: static;';
			
		$business_lawyer_firm_custom_style .='}';
	} 

	wp_add_inline_style( 'business-lawyer-firm-style',$business_lawyer_firm_custom_style );

}
add_action( 'wp_enqueue_scripts', 'business_lawyer_firm_sticky_header' );

/**
 * Enqueue theme color style.
 */
function business_lawyer_firm_theme_color() {

    $theme_color_css = '';
     $business_lawyer_firm_theme_color = get_theme_mod('business_lawyer_firm_theme_color');
    $business_lawyer_firm_theme_color_2 = get_theme_mod('business_lawyer_firm_theme_color_2');
    $business_lawyer_firm_preloader_bg_color = get_theme_mod('business_lawyer_firm_preloader_bg_color');
    $business_lawyer_firm_preloader_dot_1_color = get_theme_mod('business_lawyer_firm_preloader_dot_1_color');
    $business_lawyer_firm_preloader_dot_2_color = get_theme_mod('business_lawyer_firm_preloader_dot_2_color');

	if(get_theme_mod('business_lawyer_firm_preloader_bg_color') == '') {
		$business_lawyer_firm_preloader_bg_color = '#000';
	}
	if(get_theme_mod('business_lawyer_firm_preloader_dot_1_color') == '') {
		$business_lawyer_firm_preloader_dot_1_color = '#fff';
	}
	if(get_theme_mod('business_lawyer_firm_preloader_dot_2_color') == '') {
		$business_lawyer_firm_preloader_dot_2_color = '#b12d40';
	}

	$theme_color_css = '

		#button:hover,#button:active,.top_header,.navigation_header,.navigation-inner-box,.nav-box,.slider-box-btn a:hover,.readmore a:hover,.navigation_header,.woocommerce-account .woocommerce-MyAccount-navigation ul li:hover,.woocommerce .woocommerce-error .button:hover, .woocommerce .woocommerce-info .button:hover, .woocommerce .woocommerce-message .button:hover, .woocommerce-page .woocommerce-error .button:hover, .woocommerce-page .woocommerce-info .button:hover, .woocommerce-page .woocommerce-message .button:hover,.woocommerce input.button.alt,.pro-button a:hover,.woocommerce #respond input#submit:hover,.woocommerce a.button:hover,.woocommerce button.button:hover,.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover,a.added_to_cart.wc-forward:hover{
			background: '.esc_attr($business_lawyer_firm_theme_color).';
		}
		a,h1,h2,h3,h4,h5,h6,.readmore a,.article-box a,.main_header p{
			color: '.esc_attr($business_lawyer_firm_theme_color).';
		}
		#button,.post-navigation .nav-previous a:hover,.post-navigation .nav-next a:hover,.posts-navigation .nav-previous a:hover,.posts-navigation .nav-next a:hover,{
			border-color: '.esc_attr($business_lawyer_firm_theme_color).';
		}

		.subscribe-box,.slider-box-btn a,.sidebar input[type="submit"],.sidebar button[type="submit"],.meta-info-box,span.onsale,.pro-button a,.woocommerce #respond input#submit, .woocommerce a.button,.woocommerce button.button, .woocommerce input.button,.woocommerce #respond input#submit.alt,.woocommerce a.button.alt, .woocommerce button.button.alt,.woocommerce .woocommerce-ordering select,.woocommerce-account .woocommerce-MyAccount-navigation ul li,.main-navigation .sub-menu,.main-navigation .sub-menu > li > a:hover, .main-navigation .sub-menu > li > a:focus,.post-navigation .nav-previous a:hover,.post-navigation .nav-next a:hover,.posts-navigation .nav-previous a:hover,.posts-navigation .nav-next a:hover,.comment-respond input#submit,.sidebar h5,.sidebar .tagcloud a:hover, .sidenav .closebtn,#button,#colophon,.toggle-nav i,a.added_to_cart.wc-forward{
			background: '.esc_attr($business_lawyer_firm_theme_color_2).';
		}
		a,.top_header i,.main_header i,a.btn-text,p.price,.woocommerce ul.products li.product .price,.woocommerce div.product p.price, .woocommerce div.product span.price,.woocommerce-message::before,.woocommerce-info::before,.main-navigation .menu > li > a:hover,.widget a:hover, .widget a:focus,.sidebar ul li a:hover,.woocommerce .star-rating span::before,.top_header p{
			color: '.esc_attr($business_lawyer_firm_theme_color_2).';
		}
		.woocommerce-message,.woocommerce-info,.main-navigation .sub-menu > li{
			border-color: '.esc_attr($business_lawyer_firm_theme_color_2).';
		}

		.loading{
			background-color: '.esc_attr($business_lawyer_firm_preloader_bg_color).';
		 }
		 @keyframes loading {
		  0%,
		  100% {
		  	transform: translatey(-2.5rem);
		    background-color: '.esc_attr($business_lawyer_firm_preloader_dot_1_color).';
		  }
		  50% {
		  	transform: translatey(2.5rem);
		    background-color: '.esc_attr($business_lawyer_firm_preloader_dot_2_color).';
		  }
		}
	';
    wp_add_inline_style( 'business-lawyer-firm-style',$theme_color_css );

}
add_action( 'wp_enqueue_scripts', 'business_lawyer_firm_theme_color' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/*radio button sanitization*/
function business_lawyer_firm_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/*dropdown page sanitization*/
function business_lawyer_firm_sanitize_dropdown_pages( $page_id, $setting ) {
	$page_id = absint( $page_id );
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}
function business_lawyer_firm_sanitize_checkbox( $input ) {
	// Boolean check 
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

function business_lawyer_firm_gt_get_post_view() {
    $count = get_post_meta( get_the_ID(), 'post_views_count', true );
    return "$count views";
}
function business_lawyer_firm_gt_set_post_view() {
    $key = 'post_views_count';
    $post_id = get_the_ID();
    $count = (int) get_post_meta( $post_id, $key, true );
    $count++;
    update_post_meta( $post_id, $key, $count );
}
function business_lawyer_firm_gt_posts_column_views( $columns ) {
    $columns['post_views'] = 'Views';
    return $columns;
}
function business_lawyer_firm_gt_posts_custom_column_views( $column ) {
    if ( $column === 'post_views') {
        echo esc_html(business_lawyer_firm_gt_get_post_view());
    }
}
add_filter( 'manage_posts_columns', 'business_lawyer_firm_gt_posts_column_views' );
add_action( 'manage_posts_custom_column', 'business_lawyer_firm_gt_posts_custom_column_views' );

/**
 * Get CSS
 */

function business_lawyer_firm_getpage_css($hook) {
	if ( 'appearance_page_business-lawyer-firm-info' != $hook ) {
		return;
	}
	wp_enqueue_style( 'business-lawyer-firm-demo-style', get_template_directory_uri() . '/assets/css/demo.css' );
}
add_action( 'admin_enqueue_scripts', 'business_lawyer_firm_getpage_css' );

add_action('after_switch_theme', 'business_lawyer_firm_setup_options');

function business_lawyer_firm_setup_options () {
	wp_redirect( admin_url() . 'themes.php?page=business-lawyer-firm-info.php' );
}

if ( ! defined( 'BUSINESS_LAWYER_FIRM_CONTACT_SUPPORT' ) ) {
define('BUSINESS_LAWYER_FIRM_CONTACT_SUPPORT',__('https://wordpress.org/support/theme/business-lawyer-firm','business-lawyer-firm'));
}
if ( ! defined( 'BUSINESS_LAWYER_FIRM_REVIEW' ) ) {
define('BUSINESS_LAWYER_FIRM_REVIEW',__('https://wordpress.org/support/theme/business-lawyer-firm/reviews/#new-post','business-lawyer-firm'));
}
if ( ! defined( 'BUSINESS_LAWYER_FIRM_LIVE_DEMO' ) ) {
define('BUSINESS_LAWYER_FIRM_LIVE_DEMO',__('https://www.themagnifico.net/demo/business-lawyer-firm/','business-lawyer-firm'));
}
if ( ! defined( 'BUSINESS_LAWYER_FIRM_GET_PREMIUM_PRO' ) ) {
define('BUSINESS_LAWYER_FIRM_GET_PREMIUM_PRO',__('https://www.themagnifico.net/themes/lawyer-wordpress-theme/','business-lawyer-firm'));
}
if ( ! defined( 'BUSINESS_LAWYER_FIRM_PRO_DOC' ) ) {
define('BUSINESS_LAWYER_FIRM_PRO_DOC',__('https://www.themagnifico.net/eard/wathiqa/business-lawyer-firm-pro-doc/','business-lawyer-firm'));
}

add_action('admin_menu', 'business_lawyer_firm_themepage');
function business_lawyer_firm_themepage(){
	$theme_info = add_theme_page( __('Theme Options','business-lawyer-firm'), __('Theme Options','business-lawyer-firm'), 'manage_options', 'business-lawyer-firm-info.php', 'business_lawyer_firm_info_page' );
}

function business_lawyer_firm_info_page() {
	$user = wp_get_current_user();
	$theme = wp_get_theme();
	?>
	<div class="wrap about-wrap business-lawyer-firm-add-css">
		<div>
			<h1>
				<?php esc_html_e('Welcome To ','business-lawyer-firm'); ?><?php echo esc_html( $theme ); ?>
			</h1>
			<div class="feature-section three-col">
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Contact Support", "business-lawyer-firm"); ?></h3>
						<p><?php esc_html_e("Thank you for trying Business Lawyer Firm , feel free to contact us for any support regarding our theme.", "business-lawyer-firm"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( BUSINESS_LAWYER_FIRM_CONTACT_SUPPORT ); ?>" class="button button-primary get">
							<?php esc_html_e("Contact Support", "business-lawyer-firm"); ?>
						</a></p>
					</div>
				</div>
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Checkout Premium", "business-lawyer-firm"); ?></h3>
						<p><?php esc_html_e("Our premium theme comes with extended features like demo content import , responsive layouts etc.", "business-lawyer-firm"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( BUSINESS_LAWYER_FIRM_GET_PREMIUM_PRO ); ?>" class="button button-primary get">
							<?php esc_html_e("Get Premium", "business-lawyer-firm"); ?>
						</a></p>
					</div>
				</div>  
				<div class="col">
					<div class="widgets-holder-wrap">
						<h3><?php esc_html_e("Review", "business-lawyer-firm"); ?></h3>
						<p><?php esc_html_e("If You love Business Lawyer Firm theme then we would appreciate your review about our theme.", "business-lawyer-firm"); ?></p>
						<p><a target="_blank" href="<?php echo esc_url( BUSINESS_LAWYER_FIRM_REVIEW ); ?>" class="button button-primary get">
							<?php esc_html_e("Review", "business-lawyer-firm"); ?>
						</a></p>
					</div>
				</div>
			</div>
		</div>
		<hr>
		<h2><?php esc_html_e("Free Vs Premium","business-lawyer-firm"); ?></h2>
		<div class="business-lawyer-firm-button-container">
			<a target="_blank" href="<?php echo esc_url( BUSINESS_LAWYER_FIRM_PRO_DOC ); ?>" class="button button-primary get">
				<?php esc_html_e("Checkout Documentation", "business-lawyer-firm"); ?>
			</a>
			<a target="_blank" href="<?php echo esc_url( BUSINESS_LAWYER_FIRM_LIVE_DEMO ); ?>" class="button button-primary get">
				<?php esc_html_e("View Theme Demo", "business-lawyer-firm"); ?>
			</a>
		</div>
		<table class="wp-list-table widefat">
			<thead class="table-book">
				<tr>
					<th><strong><?php esc_html_e("Theme Feature", "business-lawyer-firm"); ?></strong></th>
					<th><strong><?php esc_html_e("Basic Version", "business-lawyer-firm"); ?></strong></th>
					<th><strong><?php esc_html_e("Premium Version", "business-lawyer-firm"); ?></strong></th>
				</tr>
			</thead>
			<tbody>
				<tr>
					<td><?php esc_html_e("Header Background Color", "business-lawyer-firm"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Navigation Logo Or Text", "business-lawyer-firm"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Hide Logo Text", "business-lawyer-firm"); ?></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Premium Support", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Fully SEO Optimized", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Recent Posts Widget", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Easy Google Fonts", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Pagespeed Plugin", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Header Image On Front Page", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Show Header Everywhere", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Custom Text On Header Image", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Full Width (Hide Sidebar)", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Only Show Upper Widgets On Front Page", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Replace Copyright Text", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Upper Widgets Colors", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Navigation Color", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Post/Page Color", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Blog Feed Color", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Footer Color", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Sidebar Color", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Customize Background Color", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
				<tr>
					<td><?php esc_html_e("Importable Demo Content	", "business-lawyer-firm"); ?></td>
					<td><span class="cross"><span class="dashicons dashicons-dismiss"></span></span></td>
					<td><span class="tick"><span class="dashicons dashicons-yes-alt"></span></span></td>
				</tr>
			</tbody>
		</table>
		<div class="business-lawyer-firm-button-container">
			<a target="_blank" href="<?php echo esc_url( BUSINESS_LAWYER_FIRM_GET_PREMIUM_PRO ); ?>" class="button button-primary get">
				<?php esc_html_e("Go Premium", "business-lawyer-firm"); ?>
			</a>
		</div>
	</div>
	<?php
}

/**
 * Change number or products per row to 3
 */
add_filter('loop_shop_columns', 'business_lawyer_firm_loop_columns', 999);
if (!function_exists('business_lawyer_firm_loop_columns')) {
	function business_lawyer_firm_loop_columns() {
		return 3;
	}
}